@@ -9,18 +9,26 @@ OC.L10N.register(
     "Current" : "Aktuálne",
     "Completed" : "Dokončené",
     "The Tasks app for Nextcloud" : "Aplikácia úloh pre Nextcloud",
+    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
+    "No users or groups" : "Žiadny používatelia alebo skupiny",
+    "can edit" : "môže upravovať ",
     "Delete" : "Zmazať",
     "Cancel" : "Zrušiť",
+    "Load all completed tasks." : "Načítať všetky ukončené úlohy",
     "Change sort order" : "Zmeniť spôsob zoradenia",
     "Default" : "Predvolené",
     "Due date" : "Termín dokončenia",
     "Sort by due date and summary." : "Zoradiť podľa termínu dokončenia a sumáru.",
     "Start date" : "Dátum začatia",
+    "Created date" : "Dátum vytvorenia",
+    "Last modified" : "Naposledy upravené",
     "Priority" : "Priorita",
     "Manually" : "Manuálne",
     "Alphabetically" : "Abecedne",
     "Task is completed" : "Úloha je dokončená",
+    "Add a task to \"{calendar}\"..." : "Pridať úlohu do kalendára \"{calendar}\"...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh","%n dokončených úloh"],
+    "Add a task to \"{calendar}\"…" : "Pridať úlohu do kalendára \"{calendar}\"…",
     "Tomorrow" : "Zajtra",
     "Set start date" : "Nastaviť dátum začatia",
     "Set due date" : "Nastaviť do dátumu",
@@ -30,6 +38,7 @@ OC.L10N.register(
     "Edit" : "Upraviť",
     "Download" : "Sťahovanie",
     "Save" : "Uložiť",
+    "Add List…" : "Pridať zoznam",
     "New List" : "Nový zoznam",
     "The name \"%s\" is already used." : "Názov \"%s\" je už použitý.",
     "An empty name is not allowed." : "Prázdny názov nie je povolený",
