@@ -10,8 +10,20 @@ OC.L10N.register(
     "Completed" : "完成",
     "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
     "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "启用后，Nextcloud 应用菜单中将显示一个新的“任务”菜单。从那里，您可以添加和删除任务，编辑其标题，描述，开始和截止日期，提醒时间，将其标记为重要，并添加注释。任务可以在用户之间共享。可以使用 CalDav 同步任务（每个任务列表链接到 Nextcloud 日历，将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal ... - 只需将日历添加为客户端中的远程日历）。您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
+    "Share with users or groups" : "和用户或者群组共享",
+    "No users or groups" : "无用户或群组",
+    "can edit" : "可编辑",
+    "Unable to delete the share." : "无法删除此共享。",
+    "Unable to change permissions." : "无法修改权限。",
     "Delete" : "删除",
     "Cancel" : "取消",
+    "Delete all completed tasks." : "删除所有已完成任务。",
+    "Delete completed tasks." : "删除已完成任务。",
+    "Deleted all completed tasks from calendar \"{calendarName}\"." : "从日历 \"{calendarName}\" 中删除所有已完成任务。",
+    "No errors" : "没有错误",
+    "Open your browser console for more details" : "打开您的浏览器控制台以获取更多详细信息",
+    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendarName}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendarName}\"._" : ["此操作将从日历 \"{calendarName}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
+    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
     "Load all completed tasks." : "载入所有已完成任务。",
     "Change sort order" : "更改排序",
     "Default" : "默认",
@@ -53,6 +65,7 @@ OC.L10N.register(
     "Set due time" : "设置截止时间",
     "All day" : "所有天",
     "Select a calendar" : "选择一个日历",
+    "Select a classification" : "选择类别",
     "Select categories" : "选择分类",
     "Add this as a new category" : "添加此项作为新的分类",
     "Task not found!" : "没有任务！",
@@ -83,6 +96,9 @@ OC.L10N.register(
     "Priority %s: medium" : "优先级 %s：中",
     "Priority %s: low" : "优先级 %s：低",
     "%s %% completed" : "%s %% 完成",
+    "When shared show full event" : "共享时显示完整事件",
+    "When shared show only busy" : "共享时仅显示进行中的事件",
+    "When shared hide this event" : "共享时隐藏本事件",
     "Last modified %s" : "上一次更改%s",
     "Created %s" : "已创建%s",
     "Completed %s" : "已完成 %s",
@@ -99,6 +115,7 @@ OC.L10N.register(
     "The name \"%s\" is already used." : "名称 \"%s\" 已被使用。",
     "An empty name is not allowed." : "不允许使用空名称。",
     "This will delete the calendar \"%s\" and all corresponding events and tasks." : "这将删除日历“%s”以及所有相应的事件和任务。",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
     "Settings" : "设置",
     "Default list" : "默认列表",
     "Visibility of Smart Collections" : "智能集合的可见性",
